@@ -17,6 +17,16 @@ $specialPageAliases['en'] = array(
 	'MathStatus' => array( 'MathStatus' ),
 );
 
+/** Arabic (العربية) */
+$specialPageAliases['ar'] = array(
+	'MathStatus' => array( 'حالة_الرياضيات' ),
+);
+
+/** Persian (فارسی) */
+$specialPageAliases['fa'] = array(
+	'MathStatus' => array( 'وضعیت_ریاضی' ),
+);
+
 /** Macedonian (македонски) */
 $specialPageAliases['mk'] = array(
 	'MathStatus' => array( 'МатСтатус' ),
