@@ -143,7 +143,7 @@ class MathTexvc extends MathRenderer {
 			'class' => 'mwe-math-fallback-image-inline tex',
 			'alt' => $this->getTex()
 		);
-		if ( $this->getMathStyle() === MW_MATHSTYLE_DISPLAY ){
+		if ( $this->getMathStyle() === 'display' ){
 			// if DisplayStyle is true, the equation will be centered in a new line
 			$attributes[ 'class' ] = 'mwe-math-fallback-image-display tex';
 		}
@@ -177,17 +177,21 @@ class MathTexvc extends MathRenderer {
 	 */
 	public function callTexvc() {
 		global $wgTexvc, $wgTexvcBackgroundColor, $wgHooks;
-
+		if ( $wgTexvc === false ){
+			$texvc = __DIR__ . '/math/texvc';
+		} else {
+			$texvc = $wgTexvc;
+		}
 		$tmpDir = wfTempDir();
-		if ( !is_executable( $wgTexvc ) ) {
+		if ( !is_executable( $texvc ) ) {
 			LoggerFactory::getInstance( 'Math' )->error(
-				"$wgTexvc does not exist or is not executable." );
+				"$texvc does not exist or is not executable." );
 			return $this->getError( 'math_notexvc' );
 		}
 
 		$escapedTmpDir = wfEscapeShellArg( $tmpDir );
 
-		$cmd = $wgTexvc . ' ' .
+		$cmd = $texvc . ' ' .
 			$escapedTmpDir . ' ' .
 			$escapedTmpDir . ' ' .
 			wfEscapeShellArg( $this->getUserInputTex() ) . ' ' .
@@ -265,7 +269,7 @@ class MathTexvc extends MathRenderer {
 			$this->setHash( $newHash );
 		}
 
-		wfRunHooks( 'MathAfterTexvc', array( &$this, &$errmsg ) );
+		Hooks::run( 'MathAfterTexvc', array( &$this, &$errmsg ) );
 
 		if ( $errmsg ) {
 			return $errmsg;
@@ -335,27 +339,7 @@ class MathTexvc extends MathRenderer {
 	 * @return string HTML string
 	 */
 	public function getHtmlOutput() {
-		if ( $this->getMode() == MW_MATH_MATHML && $this->getMathml() != '' ) {
-			return Xml::tags( 'math',
-				$this->getAttributes( 'math',
-					array( 'xmlns' => 'http://www.w3.org/1998/Math/MathML' ) ),
-				$this->mathml );
-		}
-		if ( ( $this->getMode() == MW_MATH_PNG ) || ( $this->getHtml() == '' ) ||
-			( ( $this->getMode() == MW_MATH_SIMPLE ) && ( $this->getConservativeness() != self::CONSERVATIVE ) ) ||
-			( ( $this->getMode() == MW_MATH_MODERN || $this->getMode() == MW_MATH_MATHML ) && ( $this->getConservativeness() == self::LIBERAL ) )
-		)
-		{
-			return $this->getMathImageHTML();
-		} else {
-			return Xml::tags( 'span',
-				$this->getAttributes( 'span',
-					array( 'class' => 'texhtml',
-						'dir' => 'ltr'
-					) ),
-				$this->getHtml()
-			);
-		}
+		return $this->getMathImageHTML();
 	}
 
 	/**
@@ -401,7 +385,17 @@ class MathTexvc extends MathRenderer {
 		}
 		return false;
 	}
+
 	public function getPng() {
+		global $wgHooks;
+		// Workaround for bugfix for Bug 56769
+		if ( !isset( $wgHooks['ParserAfterParse']['FlushMathBackend'] ) ) {
+			// saves the PNG-file
+			$parser = new Parser();
+			$text = '';
+			$stripState = new StripState( '' );
+			Hooks::run( 'ParserAfterParse', array( &$parser, &$text, &$stripState ) );
+		}
 		$backend = $this->getBackend();
 		return $backend->getFileContents( array( 'src' => $this->getHashPath() . "/" . $this->getHash() . '.png' ) );
 	}
