@@ -11,7 +11,7 @@
 #
 
 Given(/^I am at page that does not exist$/) do
-  visit(DoesNotExistPage, using_params: {page_name: @random_string})
+  visit(DoesNotExistPage, using_params: { page_name: @random_string })
 end
 
 When(/^I click link Create source$/) do
@@ -23,7 +23,7 @@ When(/^I click Preview$/) do
 end
 
 When(/^I type (.+)$/) do |write_text|
-  on(EditPage).article_text=write_text
+  on(EditPage).article_text = write_text
 end
 
 Then(/^alt for that img should be (.+)$/) do |alt|
@@ -31,10 +31,10 @@ Then(/^alt for that img should be (.+)$/) do |alt|
 end
 
 Then(/^src for that img should come from (.+)$/) do |src|
-  expect(on(EditPage).math_image_element.element.src).to match Regexp.escape(src)
+  expect(on(EditPage).math_image_element.element.src).to match Regexp.escape src
 end
 
 
 Then(/^the page should contain an img tag$/) do
   expect(on(EditPage).math_image_element.when_present).to be_visible
-end
\ No newline at end of file
+end
