@@ -12,8 +12,7 @@
 class DoesNotExistPage
   include PageObject
 
-  include URL
-  page_url URL.url("<%=params[:page_name]%>")
+  page_url '<%=params[:page_name]%>'
 
-  a(:create_source, text: "Create source")
-end
\ No newline at end of file
+  a(:create_source, text: 'Create source')
+end
